<?xml version="1.0" ?><!DOCTYPE TS><TS language="it_IT" version="2.0">
<context>
    <name>Badges</name>
    <message>
        <location filename="../qml/pages/Badges.qml" line="18"/>
        <source>BADGES</source>
        <translation>BADGE</translation>
    </message>
</context>
<context>
    <name>Checkin</name>
    <message>
        <location filename="../qml/pages/Checkin.qml" line="18"/>
        <source>CHECK-IN DETAILS</source>
        <translation>DETTAGLI SUL CHECK-IN</translation>
    </message>
    <message>
        <location filename="../qml/pages/Checkin.qml" line="222"/>
        <source>TOTAL POINTS</source>
        <translation>PUNTI TOTALI</translation>
    </message>
    <message>
        <location filename="../qml/pages/Checkin.qml" line="260"/>
        <source>EARNED BADGES</source>
        <translation>BADGE OTTENUTI</translation>
    </message>
    <message>
        <location filename="../qml/pages/Checkin.qml" line="282"/>
        <source>COMMENTS</source>
        <translation>COMMENTI</translation>
    </message>
</context>
<context>
    <name>CheckinDialog</name>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="22"/>
        <source>NEW CHECK-IN</source>
        <translation>NUOVO CHECK-IN</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="48"/>
        <source>CHECK IN</source>
        <translation>CHECK-IN</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="57"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="100"/>
        <source>Whats on your mind?</source>
        <translation>Che ti passa per la testa?</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="129"/>
        <source>Sharing options</source>
        <translation>Opzioni di condivisione</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="133"/>
        <source>Share with Friends</source>
        <translation>Condividi con gli Amici</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="141"/>
        <source>Post to Facebook</source>
        <translation>Condividi su Facebook</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="149"/>
        <source>Post to Twitter</source>
        <translation>Condividi su Twitter</translation>
    </message>
</context>
<context>
    <name>CheckinHistory</name>
    <message>
        <location filename="../qml/pages/CheckinHistory.qml" line="24"/>
        <source>CHECK-IN HISTORY</source>
        <translation>CRONOLOGIA CHECK-IN</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinHistory.qml" line="64"/>
        <source>Load More</source>
        <translation>Carica altro</translation>
    </message>
</context>
<context>
    <name>CommentDialog</name>
    <message>
        <location filename="../qml/components/CommentDialog.qml" line="26"/>
        <source>What is on your mind?</source>
        <translation>Che ti passa per la testa?</translation>
    </message>
    <message>
        <location filename="../qml/components/CommentDialog.qml" line="38"/>
        <source>New awesome comment</source>
        <translation>Nuovo incredibile commento</translation>
    </message>
    <message>
        <location filename="../qml/components/CommentDialog.qml" line="69"/>
        <source>Comment!</source>
        <translation>Commenta!</translation>
    </message>
    <message>
        <location filename="../qml/components/CommentDialog.qml" line="77"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>DebugSubmit</name>
    <message>
        <location filename="../qml/pages/DebugSubmit.qml" line="18"/>
        <source>DEBUG SUBMIT</source>
        <translation>INVIA DEBUG</translation>
    </message>
    <message>
        <location filename="../qml/pages/DebugSubmit.qml" line="34"/>
        <source>Thank you for submit!&lt;br&gt;This will be implemented soon!</source>
        <translation>Grazie per il tuo contributo!&lt;br&gt;Verrà analizzato al più presto!</translation>
    </message>
    <message>
        <location filename="../qml/pages/DebugSubmit.qml" line="53"/>
        <source>SUBMIT</source>
        <translation>INVIA</translation>
    </message>
    <message>
        <location filename="../qml/pages/DebugSubmit.qml" line="61"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../qml/pages/DebugSubmit.qml" line="92"/>
        <source>You can help me with Nelisquare development by submitting debug info.

The following information are going to be submitted:</source>
        <translation>Puoi aiutarmi nello sviluppo di Nelisquare inviando informazioni di debug.

Le seguenti informazioni stanno per essere inviate:</translation>
    </message>
</context>
<context>
    <name>DebugWidget</name>
    <message>
        <location filename="../qml/components/DebugWidget.qml" line="14"/>
        <source>Unknown %1 event!</source>
        <translation>Evento %1 sconosciuto!</translation>
    </message>
    <message>
        <location filename="../qml/components/DebugWidget.qml" line="47"/>
        <source>This event type is unknown.
You can help with resolution.</source>
        <translation>Questo evento è di tipo sconosciuto.
Puoi aiutare fornendo dettagli.</translation>
    </message>
</context>
<context>
    <name>FriendsFeed</name>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="43"/>
        <source>FRIENDS FEED</source>
        <translation>ATTIVITÀ</translation>
    </message>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="229"/>
        <source>RECENT</source>
        <translation>RECENTI</translation>
    </message>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="242"/>
        <source>NEARBY</source>
        <translation>NELLE VICINANZE</translation>
    </message>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="263"/>
        <source>Load More</source>
        <translation>Carica altro</translation>
    </message>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="410"/>
        <source>Sorry, Pages are not supported yet :(</source>
        <translation>Spiacente, le Pagine non sono ancora supportate :(</translation>
    </message>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="480"/>
        <source>Sorry, no lists support yet :(</source>
        <translation>Spiacente, le liste non sono ancora supportate :(</translation>
    </message>
</context>
<context>
    <name>LeaderBoard</name>
    <message>
        <location filename="../qml/pages/LeaderBoard.qml" line="19"/>
        <source>YOU ARE #%1</source>
        <translation>SEI IL #%1</translation>
    </message>
    <message>
        <location filename="../qml/pages/LeaderBoard.qml" line="63"/>
        <source>&lt;b&gt;%1 points&lt;/b&gt; %2 checkins</source>
        <translation>&lt;b&gt;%1 punti&lt;/b&gt; %2 check-in</translation>
    </message>
</context>
<context>
    <name>LikeBox</name>
    <message>
        <location filename="../qml/components/LikeBox.qml" line="33"/>
        <source>USER LIKES</source>
        <translation>È PIACIUTO A</translation>
    </message>
</context>
<context>
    <name>ListViewEx</name>
    <message>
        <location filename="../qml/components/ListViewEx.qml" line="9"/>
        <source>Pull and hold to refresh...</source>
        <translation>Tira verso il basso per aggiornare...</translation>
    </message>
    <message>
        <location filename="../qml/components/ListViewEx.qml" line="10"/>
        <source>Release to refresh...</source>
        <translation>Rilascia per aggiornare...</translation>
    </message>
</context>
<context>
    <name>Login24sq</name>
    <message>
        <location filename="../qml/pages/Login24sq.qml" line="15"/>
        <source>Sign In to Foursquare</source>
        <translation>Accedi a Foursquare</translation>
    </message>
    <message>
        <location filename="../qml/pages/Login24sq.qml" line="41"/>
        <source>Exit</source>
        <translation>Esci</translation>
    </message>
    <message>
        <location filename="../qml/pages/Login24sq.qml" line="59"/>
        <source>Error connecting to Foursquare site</source>
        <translation>Errore durante la connessione a Foursquare</translation>
    </message>
</context>
<context>
    <name>Mayorships</name>
    <message>
        <location filename="../qml/pages/Mayorships.qml" line="19"/>
        <source>MAYORSHIPS</source>
        <translation>MAYORSHIP</translation>
    </message>
</context>
<context>
    <name>NotificationDialog</name>
    <message>
        <location filename="../qml/components/NotificationDialog.qml" line="36"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>Notifications</name>
    <message>
        <location filename="../qml/pages/Notifications.qml" line="24"/>
        <source>NOTIFICATIONS</source>
        <translation>NOTIFICHE</translation>
    </message>
    <message>
        <location filename="../qml/pages/Notifications.qml" line="51"/>
        <source>Mark all as read</source>
        <translation>Segna tutte come lette</translation>
    </message>
    <message>
        <location filename="../qml/pages/Notifications.qml" line="61"/>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
</context>
<context>
    <name>PageWrapper</name>
    <message>
        <location filename="../qml/components/PageWrapper.qml" line="101"/>
        <source>Check updates</source>
        <translation>Controlla aggiornamenti</translation>
    </message>
    <message>
        <location filename="../qml/components/PageWrapper.qml" line="107"/>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <location filename="../qml/components/PageWrapper.qml" line="113"/>
        <source>Exit</source>
        <translation>Esci</translation>
    </message>
</context>
<context>
    <name>Photo</name>
    <message>
        <location filename="../qml/pages/Photo.qml" line="20"/>
        <source>PHOTO</source>
        <translation>FOTO</translation>
    </message>
    <message>
        <location filename="../qml/pages/Photo.qml" line="45"/>
        <source>You cannot save image until download is finished</source>
        <translation>Non puoi salvare l&apos;immagine prima di averla scaricata completamente</translation>
    </message>
    <message>
        <location filename="../qml/pages/Photo.qml" line="49"/>
        <source>Image saved to %1</source>
        <translation>Immagine salvata in %1</translation>
    </message>
    <message>
        <location filename="../qml/pages/Photo.qml" line="51"/>
        <source>Failed to save image</source>
        <translation>Salvataggio immagine fallito</translation>
    </message>
</context>
<context>
    <name>PhotoAdd</name>
    <message>
        <location filename="../qml/pages/PhotoAdd.qml" line="19"/>
        <source>Select photo for upload</source>
        <translation>Scegli la foto da caricare</translation>
    </message>
    <message>
        <location filename="../qml/pages/PhotoAdd.qml" line="60"/>
        <source>Error uploading photo!&lt;br&gt;Photo size should be less than %1KB</source>
        <translation>Errore nel caricamento della foto!&lt;br&gt;La dimensione della foto dovrebbe essere meno di %1KB</translation>
    </message>
</context>
<context>
    <name>PhotoShareDialog</name>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="20"/>
        <source>PHOTO UPLOAD</source>
        <translation>CARICAMENTO FOTO</translation>
    </message>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="36"/>
        <source>UPLOAD</source>
        <translation>CARICAMENTO</translation>
    </message>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="91"/>
        <source>Sharing options</source>
        <translation>Opzioni di condivisione</translation>
    </message>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="95"/>
        <source>Public</source>
        <translation>Pubblico</translation>
    </message>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="102"/>
        <source>Post to Facebook</source>
        <translation>Condividi su Facebook</translation>
    </message>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="109"/>
        <source>Post to Twitter</source>
        <translation>Condividi su Twitter</translation>
    </message>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="48"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>PhotosBox</name>
    <message>
        <location filename="../qml/components/PhotosBox.qml" line="8"/>
        <source>PHOTOS</source>
        <translation>FOTO</translation>
    </message>
</context>
<context>
    <name>PhotosGallery</name>
    <message>
        <location filename="../qml/pages/PhotosGallery.qml" line="13"/>
        <source>VENUE PHOTOS</source>
        <translation>FOTO DEL LUOGO</translation>
    </message>
</context>
<context>
    <name>SettingSlider</name>
    <message>
        <location filename="../qml/components/SettingSlider.qml" line="50"/>
        <source>Off</source>
        <translation>Disattiva</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../qml/pages/Settings.qml" line="13"/>
        <source>updating...</source>
        <translation>aggiornamento...</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="21"/>
        <source>SETTINGS</source>
        <translation>IMPOSTAZIONI</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="55"/>
        <source>2012-2013 Basil Semuonov</source>
        <translation>2012-2013 Basil Semuonov</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="56"/>
        <source>Idea by Tommi Laukkanen</source>
        <translation>Idea di Tommi Laukkanen</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="57"/>
        <source>Shout out to @knobtviker</source>
        <translation>Fai un fischio a @knobtviker</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="58"/>
        <source>Design by Kim Venetvirta</source>
        <translation>Design di Kim Venetvirta</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="59"/>
        <source>If any problems, tweet @basil_s</source>
        <translation>Se hai un qualsiasi problema, twitta a @basil_s</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="60"/>
        <source>Version</source>
        <translation>Versione</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="62"/>
        <source>Build</source>
        <translation>Build</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="64"/>
        <source>Powered by Foursquare</source>
        <translation>Powered by Foursquare</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="66"/>
        <source>Close</source>
        <translation>Chiudi</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="72"/>
        <location filename="../qml/pages/Settings.qml" line="117"/>
        <source>Reset settings</source>
        <translation>Azzera impostazioni</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="73"/>
        <source>This action will erase all data including auth token, application settings and cache.</source>
        <translation>Questa azione cancellerà tutti i dati, inclusi il token di autorizzazione, le impostazioni dell&apos;applicazione e la cache.</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="74"/>
        <source>Yes, clear the data</source>
        <translation>Sì, cancella i dati</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="75"/>
        <source>No, thanks</source>
        <translation>No, grazie</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="83"/>
        <source>Language</source>
        <translation>Lingua</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="111"/>
        <source>Notifications</source>
        <translation>Notifiche</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="163"/>
        <source>UPDATES CHECK</source>
        <translation>CONTROLLO AGGIORNAMENTI</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="188"/>
        <source>None</source>
        <translation>Nessuno</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="194"/>
        <source>Stable</source>
        <translation>Stabile</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="199"/>
        <source>Beta</source>
        <translation>Beta</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="205"/>
        <source>Alpha</source>
        <translation>Alpha</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="211"/>
        <source>INTERVALS</source>
        <translation>INTERVALLI</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="215"/>
        <source>GPS Unlock timeout</source>
        <translation>Tempo di sblocco del GPS</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="216"/>
        <source>Instant</source>
        <translation>Istantaneo</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="216"/>
        <source>%1 secs(s)</source>
        <translation>%1 sec</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="216"/>
        <location filename="../qml/pages/Settings.qml" line="225"/>
        <source>Disabled</source>
        <translation>Disattivato</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="224"/>
        <source>Feed autoupdate time</source>
        <translation>Aggiornamento attività</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="225"/>
        <source>Off</source>
        <translation>Disattiva</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="225"/>
        <source>%1 min(s)</source>
        <translation>%1 min</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="233"/>
        <source>PERMISSIONS</source>
        <translation>PERMESSI</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="236"/>
        <source>Allow use of Location Data</source>
        <translation>Permetti l&apos;uso dei dati sulla posizione</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="244"/>
        <source>Always run in background</source>
        <translation>Mantieni in esecuzione in background</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="252"/>
        <source>Enable notifications</source>
        <translation>Attiva notifiche</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="260"/>
        <source>Feed at Home screen</source>
        <translation>Feed nella Schermata Iniziale</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="268"/>
        <source>Push notifications</source>
        <translation>Notifiche push</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="319"/>
        <source>COLOR THEME</source>
        <translation>COLORE TEMA</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="338"/>
        <source>Light</source>
        <translation>Chiaro</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="347"/>
        <source>Dark</source>
        <translation>Scuro</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="356"/>
        <source>SCREEN ORIENTATION</source>
        <translation>ORIENTAMENTO SCHERMO</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="378"/>
        <source>Auto</source>
        <translation>Auto</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="384"/>
        <source>Landscape</source>
        <translation>Orizzontale</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="389"/>
        <source>Portrait</source>
        <translation>Verticale</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="395"/>
        <source>STARTUP PAGE</source>
        <translation>PAGINA INIZIALE</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="417"/>
        <source>Feed</source>
        <translation>Aggiornamenti</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="423"/>
        <source>Venues</source>
        <translation>Luoghi</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="428"/>
        <source>Self</source>
        <translation>Profilo</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="434"/>
        <source>LANGUAGE</source>
        <translation>LINGUA</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="445"/>
        <source>MAP PROVIDER</source>
        <translation>FORNITORE MAPPE</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="468"/>
        <source>Nokia</source>
        <translation>Nokia</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="474"/>
        <source>Google</source>
        <translation>Google</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="479"/>
        <source>OSM</source>
        <translation>OSM</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="497"/>
        <source>IMAGE LOADING</source>
        <translation>CARICAMENTO IMMAGINI</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="516"/>
        <source>All</source>
        <translation>Tutte</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="521"/>
        <source>Cached</source>
        <translation>Nella cache</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="527"/>
        <source>INTEGRATION WITH APPS</source>
        <translation>APP INTEGRATE</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="533"/>
        <source>Download MOLO.ME</source>
        <translation>Scarica MOLO.ME</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="552"/>
        <source>MOLO.ME Photos</source>
        <translation>Foto da MOLO.ME</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="572"/>
        <source>APPLICATION CACHE</source>
        <translation>CACHE DELL&apos;APPLICAZIONE</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="580"/>
        <source>Clear</source>
        <translation>Cancella</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="592"/>
        <source>Size: %1</source>
        <translation>Dimensione: %1</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="598"/>
        <source>UI</source>
        <translation>UI</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="601"/>
        <source>Reload UI</source>
        <translation>Ricarica UI</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="607"/>
        <source>AUTHENTICATION</source>
        <translation>AUTENTICAZIONE</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="610"/>
        <source>Reset authentication</source>
        <translation>Annulla autenticazione</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="631"/>
        <source>ACCESS RATE LIMIT</source>
        <translation>LIMITE DI ACCESSO</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="637"/>
        <source>API requests available: %1 / %2</source>
        <translation>Richieste API disponibili: %1 / %2</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="643"/>
        <source>You are low on X-RATE requests</source>
        <translation>Hai poche richieste X-RATE</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="648"/>
        <source>DEBUG</source>
        <translation>DEBUG</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="651"/>
        <source>Enable debug</source>
        <translation>Abilita debug</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="665"/>
        <source>Options will be available soon</source>
        <translation>Le opzioni saranno presto disponibili</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="680"/>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="681"/>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="682"/>
        <source>Service</source>
        <translation>Servizio</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="683"/>
        <source>Debug</source>
        <translation>Debug</translation>
    </message>
</context>
<context>
    <name>SpecialsList</name>
    <message>
        <location filename="../qml/components/SpecialsList.qml" line="13"/>
        <source>VENUE SPECIALS</source>
        <translation>PROMOZIONI</translation>
    </message>
    <message>
        <location filename="../qml/components/SpecialsList.qml" line="31"/>
        <source>Unlocked!</source>
        <translation>Sbloccato!</translation>
    </message>
</context>
<context>
    <name>TipDialog</name>
    <message>
        <location filename="../qml/components/TipDialog.qml" line="40"/>
        <source>Write some cool tip here</source>
        <translation>Scrivi un consiglio qui</translation>
    </message>
    <message>
        <location filename="../qml/components/TipDialog.qml" line="71"/>
        <source>ADD</source>
        <translation>AGGIUNGI</translation>
    </message>
    <message>
        <location filename="../qml/components/TipDialog.qml" line="79"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
</context>
<context>
    <name>TipPage</name>
    <message>
        <location filename="../qml/pages/TipPage.qml" line="22"/>
        <source>Usefull tip</source>
        <translation>Consiglio utile</translation>
    </message>
    <message>
        <location filename="../qml/pages/TipPage.qml" line="148"/>
        <source>TIP PHOTO</source>
        <translation>FOTO DEL CONSIGLIO</translation>
    </message>
    <message>
        <location filename="../qml/pages/TipPage.qml" line="170"/>
        <source>Save tip</source>
        <translation>Salva consiglio</translation>
    </message>
    <message>
        <location filename="../qml/pages/TipPage.qml" line="178"/>
        <source>Mark as done</source>
        <translation>Segna come fatto</translation>
    </message>
</context>
<context>
    <name>TipsList</name>
    <message>
        <location filename="../qml/pages/TipsList.qml" line="18"/>
        <source>TIPS LIST</source>
        <translation>LISTA CONSIGLI</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <location filename="../qml/components/UpdateDialog.qml" line="12"/>
        <source>New update available</source>
        <translation>Nuovo aggiornamento disponibile</translation>
    </message>
    <message>
        <location filename="../qml/components/UpdateDialog.qml" line="13"/>
        <source>Version: %1&lt;br&gt;Type: %2&lt;br&gt;Build: %3&lt;br&gt;&lt;br&gt;Changelog: &lt;br&gt;%4</source>
        <translation>Versione: %1&lt;br&gt;Tipo: %2&lt;br&gt;Build: %3&lt;br&gt;&lt;br&gt;Changelog: &lt;br&gt;%4</translation>
    </message>
    <message>
        <location filename="../qml/components/UpdateDialog.qml" line="19"/>
        <source>Update!</source>
        <translation>Aggiorna!</translation>
    </message>
    <message>
        <location filename="../qml/components/UpdateDialog.qml" line="20"/>
        <source>No, thanks</source>
        <translation>No, grazie</translation>
    </message>
</context>
<context>
    <name>User</name>
    <message>
        <location filename="../qml/pages/User.qml" line="60"/>
        <source>USER DETAILS</source>
        <translation>DETTAGLI UTENTE</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="69"/>
        <source>Change avatar</source>
        <translation>Cambia avatar</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="77"/>
        <source>User lists</source>
        <translation>Liste utente</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="85"/>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="91"/>
        <source>Exit</source>
        <translation>Esci</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="303"/>
        <source>Add Friend</source>
        <translation>Aggiungi Amico</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="315"/>
        <source>Approve Friend</source>
        <translation>Approva amicizia</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="322"/>
        <source>Deny friend</source>
        <translation>Nega amicizia</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="334"/>
        <source>Remove Friend</source>
        <translation>Rimuovi Amico</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="347"/>
        <source>&lt;b&gt;SCORES&lt;/b&gt; (LAST 7 DAYS)</source>
        <translation>&lt;br&gt;PUNTEGGI&lt;/b&gt; (ULTIMI 7 GIORNI)</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="352"/>
        <source>BEST SCORE</source>
        <translation>MIGLIOR PUNTEGGIO</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="410"/>
        <source>Badges</source>
        <translation>Badge</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="445"/>
        <source>Checkins</source>
        <translation>Check-in</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="480"/>
        <source>Mayorships</source>
        <translation>Mayorship</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="515"/>
        <source>Friends</source>
        <translation>Amici</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="550"/>
        <source>Photos</source>
        <translation>Foto</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="586"/>
        <source>Tips</source>
        <translation>Consigli</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="602"/>
        <source>YOU ARE #%1</source>
        <translation>SEI IL #%1</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="627"/>
        <source>&lt;b&gt;%1 points&lt;/b&gt; %2 checkins</source>
        <translation>&lt;b&gt;%1 punti&lt;/b&gt; %2 check-in</translation>
    </message>
</context>
<context>
    <name>UsersList</name>
    <message>
        <location filename="../qml/pages/UsersList.qml" line="21"/>
        <source>Loading...</source>
        <translation>Caricamento...</translation>
    </message>
    <message>
        <location filename="../qml/pages/UsersList.qml" line="30"/>
        <source>USER FRIENDS</source>
        <translation>AMICI DELL&apos;UTENTE</translation>
    </message>
    <message>
        <location filename="../qml/pages/UsersList.qml" line="33"/>
        <source>LIKERS LIST</source>
        <translation>A CHI PIACE</translation>
    </message>
</context>
<context>
    <name>Venue</name>
    <message>
        <location filename="../qml/pages/Venue.qml" line="142"/>
        <source>VENUE PHOTOS</source>
        <translation>FOTO DEL LUOGO</translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="250"/>
        <source>CHECK-IN HERE!</source>
        <translation>FAI CHECK-IN QUI!</translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="272"/>
        <source>Venue doesn&apos;t have mayor yet!</source>
        <translation>Questo luogo ancora non ha un sindaco!</translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="273"/>
        <source>is the mayor.</source>
        <translation>è il sindaco.</translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="273"/>
        <source>It could be you!</source>
        <translation>Potresti essere tu!</translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="274"/>
        <source>%1 checkins</source>
        <translation>%1 check-in</translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="317"/>
        <source>BEST TIPS</source>
        <translation>MIGLIORI CONSIGLI</translation>
    </message>
</context>
<context>
    <name>VenueAdd</name>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="32"/>
        <source>ADD NEW VENUE</source>
        <translation>AGGIUNGI NUOVO LUOGO</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="74"/>
        <source>Select category</source>
        <translation>Seleziona categoria</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="94"/>
        <source>Select sub-category</source>
        <translation>Seleziona sotto-categoria</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="131"/>
        <source>VENUE NAME</source>
        <translation>NOME LUOGO</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="136"/>
        <source>Venue name required</source>
        <translation>Nome luogo obbligatorio</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="145"/>
        <source>VENUE ADDRESS</source>
        <translation>INDIRIZZO LUOGO</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="150"/>
        <source>Street address is optional</source>
        <translation>L&apos;indirizzo è opzionale</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="159"/>
        <source>VENUE CATEGORY</source>
        <translation>CATEGORIA LUOGO</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="164"/>
        <source>Not selected</source>
        <translation>Non selezionato</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="165"/>
        <source>Tap to select category</source>
        <translation>Tocca per selezionare una categoria</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="172"/>
        <source>Venue categories are not loaded yet</source>
        <translation>Categorie dei luoghi non ancora caricate</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="182"/>
        <source>VENUE LOCATION</source>
        <translation>POSIZIONE DEL LUOGO</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="209"/>
        <source>CREATE VENUE</source>
        <translation>CREA LUOGO</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="212"/>
        <source>You should specify venue name</source>
        <translation>Dovresti specificare un nome per il luogo</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="216"/>
        <source>You should select category</source>
        <translation>Dovresti scegliere una categoria</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="220"/>
        <source>Can&apos;t get GPS position for venue</source>
        <translation>Impossibile ottenere la posizione GPS del luogo</translation>
    </message>
</context>
<context>
    <name>VenueMap</name>
    <message>
        <location filename="../qml/pages/VenueMap.qml" line="213"/>
        <source>GET ROUTE</source>
        <translation>OTTIENI INDICAZIONI</translation>
    </message>
</context>
<context>
    <name>VenuesList</name>
    <message>
        <location filename="../qml/pages/VenuesList.qml" line="23"/>
        <source>NEARBY VENUES</source>
        <translation>LUOGHI NELLE VICINANZE</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenuesList.qml" line="38"/>
        <source>GPS signal is fuzzy, cannot get your location</source>
        <translation>Segnale GPS disturbato, impossibile ottenere posizione</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenuesList.qml" line="125"/>
        <source>Locking GPS, please wait</source>
        <translation>Rilevamento GPS, attendere</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenuesList.qml" line="141"/>
        <source>Tap to search place...</source>
        <translation>Tocca per cercare un luogo...</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenuesList.qml" line="157"/>
        <source>SEARCH</source>
        <translation>CERCA</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenuesList.qml" line="198"/>
        <source>ADD NEW VENUE</source>
        <translation>AGGIUNGI NUOVO LUOGO</translation>
    </message>
</context>
<context>
    <name>Welcome</name>
    <message>
        <location filename="../qml/pages/Welcome.qml" line="29"/>
        <source>Welcome!</source>
        <translation>Benvenuto!</translation>
    </message>
    <message>
        <location filename="../qml/pages/Welcome.qml" line="46"/>
        <source>Please, login with Foursquare!</source>
        <translation>Per favore, accedi a Foursquare!</translation>
    </message>
    <message>
        <location filename="../qml/pages/Welcome.qml" line="53"/>
        <source>Login</source>
        <translation>Accedi</translation>
    </message>
    <message>
        <location filename="../qml/pages/Welcome.qml" line="67"/>
        <source>Foursquare privacy policy</source>
        <translation>Informativa sulla privacy di Foursquare</translation>
    </message>
    <message>
        <location filename="../qml/pages/Welcome.qml" line="81"/>
        <source>Nelisquare privacy policy</source>
        <translation>Informativa sulla privacy di Nelisquare</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../qml/main.qml" line="387"/>
        <source>Location data</source>
        <translation>Dati sulla posizione</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="388"/>
        <source>Nelisquare requires use of user location data. Data is needed to make geo-location services work properly.</source>
        <translation>Nelisquare ha bisogno di utilizzare i dati sulla posizione dell&apos;utente. Questi dati sono necessari per il corretto funzionamento dei servizi di geo-localizzazione.</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="389"/>
        <source>Allow</source>
        <translation>Permetti</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="390"/>
        <source>Deny</source>
        <translation>Nega</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="402"/>
        <source>Push notifications</source>
        <translation>Notifiche push</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="403"/>
        <source>Incoming push notifications are not supported at this version and are disabled by default.&lt;br/&gt;&lt;br/&gt;You will be promted again when they will be available at future versions.</source>
        <translation>Le notifiche push non sono supportate in questa versione e sono disattivate. &lt;br/&gt;&lt;br/&gt;Ti verrà chiesto se vuoi attivarle quando saranno abilitate in una futura versione.</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="407"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="124"/>
        <source>Check updates</source>
        <translation>Controlla aggiornamenti</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="130"/>
        <source>Settings</source>
        <translation>Impostazioni</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="136"/>
        <source>Exit</source>
        <translation>Esci</translation>
    </message>
</context>
</TS>